import org.apache.tools.ant.*;
import org.apache.tools.ant.taskdefs.*;
import java.io.File;

/**
 * Returns a path, based on the given path, which does not exist on the filesystem
 * If the given path doesn't exist on the system, just returns the path
 * If the given path does exist, return the path appended with "(n)" where
 * where n is the lowest possible integer greater than 1 which would result in a
 * path that does not exist on the file system.
 */
public class GetFreePath extends Task {

	private File path = null;
	private String property = null;

	/**
	 * for testing
	 */
	public static void main( String[] args ) {

		GetFreePath gfp = new GetFreePath();
		gfp.setPath( new File(args[0]) );
		gfp.setProperty( args[1] );
		gfp.execute();

	}

	public void execute() {

		//check both attributes set
		if ( path == null ) {
			throw new BuildException( "Error - No path specified !!" );
		}

		if ( property == null ) {
			throw new BuildException( "Error - No property specified !!" );
		}

		//find a free path
		File returnPath = new File(path.getPath());
		for ( int i=2; returnPath.exists(); i++ ) {
			returnPath = new File(path.getPath() + "(" + i + ")" );
		}

		//set the found path in the project
		Project pr = getProject();
		if ( pr != null ) {
			pr.setProperty( "property", returnPath.getPath() );
		}
		System.out.println(returnPath.getPath());
		

	}

   
	public void setPath(File path) {
		this.path = path;
	}

	public void setProperty(String property) {
		this.property = property;
	}

}
